import React, { useState } from 'react';
import { ShoppingBag, Search, Sun, Moon, X, Menu, ChevronDown, ChevronRight, Phone, Mail, MapPin } from 'lucide-react';
import { useTranslation } from 'react-i18next';
import { GB, TR, RU, UA, DE } from 'country-flag-icons/react/3x2';
import { useTheme } from '../components/context/ThemeContext';
import { useNavigate } from 'react-router-dom';

function App() {
  const { t, i18n } = useTranslation();
  const [isSearchOpen, setIsSearchOpen] = useState(false);
  const [isLangOpen, setIsLangOpen] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const [activeMobileCategory, setActiveMobileCategory] = useState('');
  const [searchQuery, setSearchQuery] = useState('');
  const { isDarkMode, setIsDarkMode } = useTheme();
  const navigate = useNavigate();
  const languages = [
    { code: 'tr', name: 'Türkçe', flag: TR },
    { code: 'en', name: 'English', flag: GB },
    { code: 'ru', name: 'Русский', flag: RU },
    { code: 'uk', name: 'Українська', flag: UA },
    { code: 'de', name: 'Deutsch', flag: DE }
  ];

  const getCurrentFlag = () => {
    const currentLang = languages.find(lang => lang.code === i18n.language);
    return currentLang ? currentLang.flag : TR;
  };
  const handleSearch = (e: React.FormEvent) => {
    e.preventDefault();
    if (searchQuery.trim()) {
      navigate(`/search?q=${encodeURIComponent(searchQuery.trim())}`);
      setIsSearchOpen(false);
      setSearchQuery('');
    }
  };
  const CurrentFlag = getCurrentFlag();

  const handleLanguageChange = (langCode: string) => {
    i18n.changeLanguage(langCode);
    localStorage.setItem('language', langCode);
    setIsLangOpen(false);
  };

  // Updated categories with hardcoded URLs
  const categories = {
    [t('categories.Rezistanslar.name')]: {
      url: '/rezistanslar',
      subcategories: [
        { 
          name: t('categories.Rezistanslar.subcategories.Fişek Rezistans'),
          url: '/product/fisekrezistans'
        },
        { 
          name: t('categories.Rezistanslar.subcategories.Boru Rezistans'),
          url: '/product/borurezistans'
        },
        { 
          name: t('categories.Rezistanslar.subcategories.Sıcak Yolluk Rezistnsı'),
          url: '/product/sicakyollukrezistans'
        },
        { 
          name: t('categories.Rezistanslar.subcategories.Mika İzılasyonlu Rezistans'),
          url: '/product/mikarezistans'
        },
        { 
          name: t('categories.Rezistanslar.subcategories.Seramik İzılasyonlu Rezistans'),
          url: '/product/seramikrezistans'
        },
        { 
          name: t('categories.Rezistanslar.subcategories.Manifold Rezistans'),
          url: '/product/manifoldrezistans'
        },
        { 
          name: t('categories.Rezistanslar.subcategories.Uç Rezistans'),
          url: '/product/ucrezistans'
        },
        { 
          name: t('categories.Rezistanslar.subcategories.Serpantinli Rezistans'),
          url: '/product/serpatinlirezistans'
        },
        { 
          name: t('categories.Rezistanslar.subcategories.Thermocouple Rezistans'),
          url: '/product/thermocouplerezistans'
        }
      ]
    },
    [t('categories.Sıcak Yolluk Sistemleri.name')]: {
      url: '/product/sicakyolluksistemleri',
      subcategories: [
        { 
          name: t('categories.Sıcak Yolluk Sistemleri.subcategories.Sıcak Yolluk Ünite'),
          url: '/sicak-yolluk-sistemleri/sicak-yolluk-unite'
        }
      ]
    },
    [t('categories.Dirençler.name')]: {
      url: '/direncler',
      subcategories: [
        { 
          name: t('categories.Dirençler.subcategories.Aluminyum Direnç'),
          url: '/product/aluminiumdirenc' 
        },
        { 
          name: t('categories.Dirençler.subcategories.Kutulu Direnç'),
          url: '/product/kutuludirenc'
        }
      ]
    },
    [t('categories.Pano Isıtıcısı.name')]: {
      url: '/product/panoisitici',
      subcategories: [
        { 
          name: t('categories.Pano Isıtıcısı.subcategories.Pano Isııtıcısı'),
          url: '/pano-isiticisi/panoisitici'
        }
      ]
    }
  };

  const contactInfo = {
    phone: '+90 539 362 1233',
    email: 'mahmut@orionrezistans.com',
    address: 'Şerifali, Edep Sk. No:38, 34776 Ümraniye/İstanbul'
  };

  const shouldShowSubcategories = (category: string) => {
    const noSubCategories = [
      t('categories.Sıcak Yolluk Sistemleri.name'),
      t('categories.Pano Isıtıcısı.name')
    ];
    return !noSubCategories.includes(category);
  };

  const SearchModal = () => (
    <div className="fixed inset-0 z-50">
      <div 
        className="absolute inset-0 bg-black/50 backdrop-blur-md"
        onClick={() => setIsSearchOpen(false)}
      />
      
      <div className="relative w-full max-w-xl mx-auto mt-36">
        <div className={`${
          isDarkMode ? 'bg-zinc-800 ring-zinc-700' : 'bg-white/95 ring-gray-200'
        } rounded-2xl shadow-2xl ring-1 backdrop-blur-sm p-6`}>
          <button
            onClick={() => setIsSearchOpen(false)}
            className={`absolute right-2 top-2 p-2 transition-all duration-200 hover:scale-105 ${
              isDarkMode 
                ? 'text-zinc-300 hover:text-emerald-300' 
                : 'text-gray-600 hover:text-blue-600'
            }`}
            aria-label="Close search"
          >
            <X className="h-5 w-5" />
          </button>
  
          <h2 className={`text-lg font-medium mb-4 ${
            isDarkMode ? 'text-zinc-200' : 'text-gray-800'
          }`}>
            {t('search.1')}
          </h2>
  
          <form onSubmit={handleSearch} className="space-y-3">
            <div className={`flex items-center gap-3 ${
              isDarkMode ? 'bg-zinc-700/80' : 'bg-gray-50/70'
            } rounded-xl p-3 ring-1 ${
              isDarkMode ? 'ring-zinc-600' : 'ring-gray-200/50'
            }`}>
              <Search className={isDarkMode ? 'text-zinc-300' : 'text-gray-500'} />
              <input
                type="text"
                value={searchQuery}
                onChange={(e) => setSearchQuery(e.target.value)}
                placeholder={t('search.placeholder')}
                className={`w-full outline-none text-lg bg-transparent ${
                  isDarkMode 
                    ? 'text-zinc-100 placeholder-zinc-400' 
                    : 'text-gray-900 placeholder-gray-500'
                }`}
                autoFocus
              />
              <button
                type="submit"
                className={`px-4 py-2 rounded-lg transition-all duration-200 hover:scale-105 ${
                  isDarkMode 
                    ? 'bg-zinc-600 hover:bg-zinc-500 text-emerald-300 hover:text-emerald-200' 
                    : 'bg-white hover:bg-gray-50 text-blue-600 hover:text-blue-700 shadow-sm ring-1 ring-gray-200'
                }`}
              >
                {t('search.2')}
              </button>
            </div>
          </form>
        </div>
      </div>
    </div>
  );

  return (
    <>
      <header className={`fixed w-full top-0 z-40 transition-colors duration-200 ${
        isDarkMode 
          ? 'bg-black text-white border-b border-zinc-900' 
          : 'bg-white text-gray-900 border-b border-gray-200'
      }`}>
        <div className="max-w-7xl mx-auto px-4">
          <div className="flex items-center justify-between h-16 md:h-24">
            {/* Logo */}
            <div className="flex-shrink-0 ml-2">
              <img 
                src="/photos/dinamikLOGO.png" 
                alt="Logo" 
                className="h-10 md:h-16 w-auto"
              />
            </div>

            {/* Desktop Navigation and Controls */}
            <div className="hidden md:flex items-center space-x-6">
              {/* Navigation Links */}
              <nav className="flex items-center space-x-6">
                <a 
                  href="/" 
                  className={`relative group px-3 py-2 text-sm font-medium transition-all duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:text-emerald-400' 
                      : 'text-gray-700 hover:text-blue-600'
                  }`}
                >
                  <span>{t('nav.home')}</span>
                  <span className={`absolute bottom-0 left-0 w-full h-0.5 transform scale-x-0 transition-transform duration-200 group-hover:scale-x-100 ${
                    isDarkMode ? 'bg-emerald-400' : 'bg-blue-600'
                  }`}></span>
                </a>
                
                <a 
                  href="/products" 
                  className={`relative group px-3 py-2 text-sm font-medium transition-all duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:text-emerald-400' 
                      : 'text-gray-700 hover:text-blue-600'
                  }`}
                >
                  <span>{t('nav.allproducts')}</span>
                  <span className={`absolute bottom-0 left-0 w-full h-0.5 transform scale-x-0 transition-transform duration-200 group-hover:scale-x-100 ${
                    isDarkMode ? 'bg-emerald-400' : 'bg-blue-600'
                  }`}></span>
                </a>

                <div className="relative group">
                  <button className={`flex items-center px-3 py-2 text-sm font-medium transition-all duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:text-emerald-400' 
                      : 'text-gray-700 hover:text-blue-600'
                  }`}>
                    <span>{t('nav.products')}</span>
                    <ChevronDown className="ml-1 w-4 h-4 transition-transform duration-200 group-hover:rotate-180" />
                  </button>
                  
                  <div className={`absolute left-0 mt-2 w-64 rounded-lg shadow-xl transform opacity-0 scale-95 transition-all duration-200 origin-top-left invisible
                    group-hover:opacity-100 group-hover:scale-100 group-hover:visible ${
                      isDarkMode 
                        ? 'bg-zinc-900 ring-1 ring-zinc-800' 
                        : 'bg-white ring-1 ring-black ring-opacity-5'
                    }`}>
                    {Object.entries(categories).map(([category, { url, subcategories }]) => (
                      <div key={category} className="group/item relative">
                        <a
                          href={url}
                          className={`flex items-center justify-between px-4 py-2 text-sm rounded-lg transition-colors duration-200 ${
                            isDarkMode
                              ? 'text-zinc-300 bg-zinc-900 hover:bg-zinc-800 hover:text-emerald-400'
                              : 'text-gray-700 bg-white hover:bg-gray-100 hover:text-blue-600'
                          }`}
                        >
                          <span>{category}</span>
                          {shouldShowSubcategories(category) && <ChevronRight className="h-4 w-4" />}
                        </a>

                        {shouldShowSubcategories(category) && (
                          <div className={`absolute left-full top-0 w-48 rounded-lg shadow-xl py-2 ml-2 transform opacity-0 scale-95 transition-all duration-200 origin-left invisible
                            group-hover/item:opacity-100 group-hover/item:scale-100 group-hover/item:visible ${
                              isDarkMode
                                ? 'bg-zinc-900 ring-1 ring-zinc-800'
                                : 'bg-white ring-1 ring-black ring-opacity-5'
                            }`}>
                            {subcategories.map((sub) => (
                              <a
                                key={sub.name}
                                href={sub.url}
                                className={`block px-4 py-2 text-sm rounded-lg transition-colors duration-200 ${
                                  isDarkMode
                                    ? 'text-zinc-300 hover:bg-zinc-800 hover:text-emerald-400'
                                    : 'text-gray-700 hover:bg-gray-100 hover:text-blue-600'
                                }`}
                              >
                                {sub.name}
                              </a>
                            ))}
                          </div>
                        )}
                      </div>
                    ))}
                  </div>
                </div>

                <a 
                  href="/about" 
                  className={`relative group px-3 py-2 text-sm font-medium transition-all duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:text-emerald-400' 
                      : 'text-gray-700 hover:text-blue-600'
                  }`}
                >
                  <span>{t('nav.about')}</span>
                  <span className={`absolute bottom-0 left-0 w-full h-0.5 transform scale-x-0 transition-transform duration-200 group-hover:scale-x-100 ${
                    isDarkMode ? 'bg-emerald-400' : 'bg-blue-600'
                  }`}></span>
                </a>
              </nav>

              {/* Controls */}
              <div className="flex items-center space-x-4 border-l pl-6">
                <button
                  onClick={() => setIsSearchOpen(true)}
                  className={`p-2 rounded-full transition-colors duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:bg-zinc-800 hover:text-emerald-400' 
                      : 'text-gray-700 hover:bg-gray-100 hover:text-blue-600'
                  }`}
                >
                  <Search className="h-5 w-5" />
                </button>

                <div className="relative">
                  <button
                    onClick={() => setIsLangOpen(!isLangOpen)}
                    className={`p-2 rounded-full transition-colors duration-200 ${
                      isDarkMode 
                        ? 'text-zinc-400 hover:bg-zinc-800 hover:text-emerald-400' 
                        : 'text-gray-700 hover:bg-gray-100 hover:text-blue-600'
                    }`}
                  >
                    <CurrentFlag className="w-5 h-4" />
                  </button>

                  {isLangOpen && (
                    <div className={`absolute right-0 mt-2 w-48 rounded-lg shadow-lg py-1 transform opacity-100 scale-100 transition-all duration-200 ${
                      isDarkMode 
                        ? 'bg-zinc-900 ring-1 ring-zinc-800' 
                        : 'bg-white ring-1 ring-black ring-opacity-5'
                    }`}>
                      {languages.map(({ code, name, flag: Flag }) => (
                        <button
                          key={code}
                          className={`flex items-center w-full px-4 py-2 text-sm ${
                            isDarkMode 
                              ? 'text-zinc-300 hover:bg-zinc-800 hover:text-emerald-400' 
                              : 'text-gray-700 hover:bg-gray-50 hover:text-blue-600'
                          } transition-colors duration-200`}
                          onClick={() => handleLanguageChange(code)}
                        >
                          <Flag className="w-5 h-4 mr-3" />
                          <span>{name}</span>
                          {i18n.language === code && (
                            <span className={`ml-auto ${isDarkMode ? 'text-emerald-400' : 'text-blue-600'}`}>✓</span>
                          )}
                        </button>
                      ))}
                    </div>
                  )}
                </div>

                <button
                  onClick={() => setIsDarkMode(!isDarkMode)}
                  className={`p-2 rounded-full transition-colors duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:bg-zinc-800 hover:text-emerald-400' 
                      : 'text-gray-700 hover:bg-gray-100 hover:text-blue-600'
                  }`}
                >
                  {isDarkMode ? (
                    <Sun className="h-5 w-5" />
                  ) : (
                    <Moon className="h-5 w-5" />
                  )}
                </button>
              </div>
            </div>

            {/* Mobile Controls */}
            <div className="md:hidden flex items-center space-x-2">
              <button
                onClick={() => setIsSearchOpen(true)}
                className={`p-2 rounded-full transition-colors duration-200 ${
                  isDarkMode 
                    ? 'text-zinc-400 hover:bg-zinc-800 hover:text-emerald-400' 
                    : 'text-gray-700 hover:bg-gray-100 hover:text-blue-600'
                }`}
              >
                <Search className="h-5 w-5" />
              </button>

              <div className="relative">
                <button
                  onClick={() => setIsLangOpen(!isLangOpen)}
                  className={`p-2 rounded-full transition-colors duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-400 hover:bg-zinc-800 hover:text-emerald-400' 
                      : 'text-gray-700 hover:bg-gray-100 hover:text-blue-600'
                  }`}
                >
                  <CurrentFlag className="w-5 h-4" />
                </button>

                {isLangOpen && (
                  <div className={`absolute right-0 mt-2 w-48 rounded-lg shadow-lg py-1 transform opacity-100 scale-100 transition-all duration-200 ${
                    isDarkMode 
                      ? 'bg-zinc-900 ring-1 ring-zinc-800' 
                      : 'bg-white ring-1 ring-black ring-opacity-5'
                  }`}>
                    {languages.map(({ code, name, flag: Flag }) => (
                      <button
                        key={code}
                        className={`flex items-center w-full px-4 py-2 text-sm ${
                          isDarkMode 
                            ? 'text-zinc-300 hover:bg-zinc-800 hover:text-emerald-400' 
                            : 'text-gray-700 hover:bg-gray-50 hover:text-blue-600'
                        } transition-colors duration-200`}
                        onClick={() => handleLanguageChange(code)}
                      >
                        <Flag className="w-5 h-4 mr-3" />
                        <span>{name}</span>
                        {i18n.language === code && (
                          <span className={`ml-auto ${isDarkMode ? 'text-emerald-400' : 'text-blue-600'}`}>✓</span>
                        )}
                      </button>
                    ))}
                  </div>
                )}
              </div>

              <button
                onClick={() => setIsDarkMode(!isDarkMode)}
                className={`p-2 rounded-full transition-colors duration-200 ${
                  isDarkMode 
                    ? 'text-zinc-400 hover:bg-zinc-800 hover:text-emerald-400' 
                    : 'text-gray-700 hover:bg-gray-100 hover:text-blue-600'
                }`}
              >
                {isDarkMode ? (
                  <Sun className="h-5 w-5" />
                ) : (
                  <Moon className="h-5 w-5" />
                )}
              </button>

              <button
                onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
                className={`p-2 rounded-full transition-colors duration-200 ${
                  isDarkMode 
                    ? 'text-zinc-400 hover:bg-zinc-800 hover:text-emerald-400' 
                    : 'text-gray-700 hover:bg-gray-100 hover:text-blue-600'
                }`}
              >
                {isMobileMenuOpen ? (
                  <X className="h-5 w-5" />
                ) : (
                  <Menu className="h-5 w-5" />
                )}
              </button>
            </div>
          </div>
        </div>
      </header>

      {/* Mobile Menu */}
      {isMobileMenuOpen && (
        <div className="md:hidden fixed inset-0 z-30">
          <div 
            className="absolute inset-0 bg-black/20 backdrop-blur-sm"
            onClick={() => setIsMobileMenuOpen(false)}
          />
          
          <div className={`absolute top-16 right-0 w-4/5 max-w-sm h-[calc(100vh-4rem)] transform transition-transform duration-300 ease-in-out overflow-y-auto ${
            isDarkMode 
              ? 'bg-black ring-1 ring-zinc-800' 
              : 'bg-white ring-1 ring-black ring-opacity-5'
          }`}>
            <div className="py-2">
              <a
                href="/"
                className={`block px-6 py-3 text-base ${
                  isDarkMode 
                    ? 'text-zinc-300 hover:bg-zinc-800 hover:text-emerald-400' 
                    : 'text-gray-700 hover:bg-gray-50 hover:text-blue-600'
                } transition-colors duration-200`}
              >
                {t('nav.home')}
              </a>

              <a
                href="/products"
                className={`block px-6 py-3 text-base ${
                  isDarkMode 
                    ? 'text-zinc-300 hover:bg-zinc-800 hover:text-emerald-400' 
                    : 'text-gray-700 hover:bg-gray-50 hover:text-blue-600'
                } transition-colors duration-200`}
              >
                {t('nav.allproducts')}
              </a>

              <div>
                <button
                  onClick={() => setActiveMobileCategory(
                    activeMobileCategory === 'categories' ? '' : 'categories'
                  )}
                  className={`flex items-center justify-between w-full px-6 py-3 text-base ${
                    isDarkMode 
                      ? 'text-zinc-300 hover:bg-zinc-800 hover:text-emerald-400' 
                      : 'text-gray-700 hover:bg-gray-50 hover:text-blue-600'
                  } transition-colors duration-200`}
                >
                  <span>{t('nav.products')}</span>
                  <ChevronDown className={`h-4 w-4 transform transition-transform duration-200 ${
                    activeMobileCategory === 'categories' ? 'rotate-180' : ''
                  }`} />
                </button>
                {activeMobileCategory === 'categories' && (
                  <div className={`${
                    isDarkMode ? 'bg-zinc-900' : 'bg-gray-50'
                  } animate-fadeIn`}>
                    {Object.entries(categories).map(([category, { url, subcategories }]) => (
                      <a
                        key={category}
                        href={url}
                        className={`block px-8 py-2 text-base ${
                          isDarkMode 
                            ? 'text-zinc-300 hover:bg-black hover:text-emerald-400' 
                            : 'text-gray-600 hover:bg-gray-100 hover:text-blue-600'
                        } transition-colors duration-200`}
                      >
                        {category}
                      </a>
                    ))}
                  </div>
                )}
              </div>

              <a
                href="/about"
                className={`block px-6 py-3 text-base ${
                  isDarkMode 
                    ? 'text-zinc-300 hover:bg-zinc-800 hover:text-emerald-400' 
                    : 'text-gray-700 hover:bg-gray-50 hover:text-blue-600'
                } transition-colors duration-200`}
              >
                {t('nav.about')}
              </a>
            </div>

            <div className={`p-6 border-t ${isDarkMode ? 'border-zinc-800' : 'border-gray-200'}`}>
              <h3 className={`text-lg font-semibold mb-4 ${isDarkMode ? 'text-zinc-200' : 'text-gray-900'}`}>
                {t('contact.title')}
              </h3>
              <div className="space-y-4">
                <a 
                  href={`tel:${contactInfo.phone}`} 
                  className={`flex items-center space-x-3 transition-colors duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-300 hover:text-emerald-400' 
                      : 'text-gray-600 hover:text-blue-600'
                  }`}
                >
                  <Phone className={isDarkMode ? 'text-emerald-400' : 'text-blue-500'} />
                  <span>{contactInfo.phone}</span>
                </a>
                <a 
                  href={`mailto:${contactInfo.email}`} 
                  className={`flex items-center space-x-3 transition-colors duration-200 ${
                    isDarkMode 
                      ? 'text-zinc-300 hover:text-emerald-400' 
                      : 'text-gray-600 hover:text-blue-600'
                  }`}
                >
                  <Mail className={isDarkMode ? 'text-emerald-400' : 'text-blue-500'} />
                  <span>{contactInfo.email}</span>
                </a>
                <div className={`flex items-center space-x-3 ${
                  isDarkMode ? 'text-zinc-300' : 'text-gray-600'
                }`}>
                  <MapPin className={isDarkMode ? 'text-emerald-400' : 'text-blue-500'} />
                  <span>{contactInfo.address}</span>
                </div>
              </div>
            </div>
          </div>
        </div>
      )}

      {/* Search Modal */}
      {isSearchOpen && <SearchModal />}

      {/* Header Spacer */}
      <div className={`h-16 md:h-20 ${isDarkMode ? 'bg-black' : 'bg-white'}`} />

    </>
  );
}

export default App;
